from enum import Enum


class EdupaidSubscriptionStatus(str, Enum):
    PAID = "PAID"
    PAYMENT_DUE = "PAYMENT_DUE"
    LOCKED = "LOCKED"
    PAYMENT_FAILED = "PAYMENT_FAILED"
    NOT_SUBSCRIBED = "NOT_SUBSCRIBED"
    API_ERROR = "API_ERROR"
    BAD_REQUEST = "BAD_REQUEST"
    UNAUTHORIZED = "UNAUTHORIZED"
    STUDENT_NOT_FOUND = "STUDENT_NOT_FOUND"
    SERVER_ERROR = "SERVER_ERROR"
    UNEXPECTED_ERROR = "UNEXPECTED_ERROR"
    TIMEOUT = "TIMEOUT"
    CONNECTION_ERROR = "CONNECTION_ERROR"
